BryanDavis has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/278207

Change subject: Rename ApiRequest to ApiAction
......................................................................

Rename ApiRequest to ApiAction

Half of the work needed for handling this logging stream was done using
the channel name "ApiRequest" and the other half was done under the name
"ApiAction". The ApiRequest naming is easier to change at this point.

Bug: T108618
Change-Id: I5797731abeba22ef6ced7c8407ee670344d35b3d
---
M includes/api/ApiMain.php
1 file changed, 2 insertions(+), 2 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/07/278207/1

diff --git a/includes/api/ApiMain.php b/includes/api/ApiMain.php
index 074cca5..df3f516 100644
--- a/includes/api/ApiMain.php
+++ b/includes/api/ApiMain.php
@@ -1401,8 +1401,8 @@
                }
 
                wfDebugLog( 'api', $msg, 'private' );
-               // ApiRequest channel is for structured data consumers
-               wfDebugLog( 'ApiRequest', '', 'private', $logCtx );
+               // ApiAction channel is for structured data consumers
+               wfDebugLog( 'ApiAction', '', 'private', $logCtx );
        }
 
        /**

-- 
To view, visit https://gerrit.wikimedia.org/r/278207
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I5797731abeba22ef6ced7c8407ee670344d35b3d
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: wmf/1.27.0-wmf.17
Gerrit-Owner: BryanDavis <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to